#[non_exhaustive]pub enum Error {
Protocol(String),
Serialize(Error),
Socket(Error),
Timeout,
Command {
cmd: String,
params: String,
error: String,
},
SocketNotFound(String),
OvsNotRunning,
OvsInvalidResponse {
cmd: String,
response: String,
error: String,
},
}Expand description
A unified error type for anything returned by a method in this crate.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Protocol(String)
Something in the jsonrpc protocol failed
Serialize(Error)
Serialization or deserialization of data failed
Socket(Error)
An error occurred in the socket I/O handling
Timeout
The connection timed-out waiting for a response
Command
The remote peer returned an error
SocketNotFound(String)
An error occurred when trying to find the right unix socket
OvsNotRunning
OpenvSwitch is not running
OvsInvalidResponse
A builtin OpenvSwitch command returned invalid data